==> carbon-component-mapper-3.11.0.tgz: package/esm/form-template/form-template.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import React from 'react';
import PropTypes from 'prop-types';
import clsx from 'clsx';
import createUseStyles from "react-jss/dist/react-jss.esm.js";
import CarbonForm from "carbon-components-react/es/components/Form/Form.js";
import CarbonButton from "carbon-components-react/es/components/Button/Button.js";
import ButtonSet from "carbon-components-react/es/components/ButtonSet/ButtonSet.js";
import FormTemplate from '@data-driven-forms/common/form-template';
var useStyles = createUseStyles({
  buttons: {
    marginTop: 48
  },
  header: {
    marginBottom: 40,
    div: {
      marginTop: 8
    }
  },
  form: {
    '&>:not(:last-child)': {
      marginBottom: 32
    }
  }
});
export var Button = function Button(_ref) {
  var label = _ref.label,
      buttonType = _ref.buttonType,
      props = _objectWithoutProperties(_ref, ["label", "buttonType"]);

  return /*#__PURE__*/React.createElement(CarbonButton, _extends({
    kind: buttonType === 'submit' ? 'primary' : 'secondary'
  }, props), label);
};
Button.propTypes = {
  label: PropTypes.oneOfType([PropTypes.arrayOf(PropTypes.node), PropTypes.node]),
  buttonType: PropTypes.string
};
export var ButtonGroup = function ButtonGroup(_ref2) {
  var children = _ref2.children,
      className = _ref2.className,
      props = _objectWithoutProperties(_ref2, ["children", "className"]);

  var _useStyles = useStyles(),
      butttons = _useStyles.butttons;

  return /*#__PURE__*/React.createElement(ButtonSet, _extends({}, props, {
    className: clsx(butttons, className)
  }), children);
};
ButtonGroup.propTypes = {
  children: PropTypes.oneOfType([PropTypes.arrayOf(PropTypes.node), PropTypes.node]),
  className: PropTypes.string
};
export var Title = function Title(_ref3) {
  var children = _ref3.children,
      props = _objectWithoutProperties(_ref3, ["children"]);

  return /*#__PURE__*/React.createElement("h3", props, children);
};
Title.propTypes = {
  children: PropTypes.oneOfType([PropTypes.arrayOf(PropTypes.node), PropTypes.node])
};
export var Description = function Description(_ref4) {
  var children = _ref4.children,
      props = _objectWithoutProperties(_ref4, ["children"]);

  return /*#__PURE__*/React.createElement("div", props, children);
};
Description.propTypes = {
  children: PropTypes.oneOfType([PropTypes.arrayOf(PropTypes.node), PropTypes.node])
};
export var Form = function Form(_ref5) {
  var children = _ref5.children,
      className = _ref5.className,
      props = _objectWithoutProperties(_ref5, ["children", "className"]);

  var _useStyles2 = useStyles(),
      form = _useStyles2.form;

  return /*#__PURE__*/React.createElement(CarbonForm, _extends({
    noValidate: true
  }, props, {
    className: clsx(form, className)
  }), children);
};
Form.propTypes = {
  children: PropTypes.oneOfType([PropTypes.arrayOf(PropTypes.node), PropTypes.node]),
  className: PropTypes.string
};
export var Header = function Header(props) {
  var _useStyles3 = useStyles(),
      header = _useStyles3.header;

  return /*#__PURE__*/React.createElement("div", _extends({
    className: header
  }, props));
};

var WrappedFormTemplate = function WrappedFormTemplate(props) {
  return /*#__PURE__*/React.createElement(FormTemplate, _extends({
    FormWrapper: Form,
    Button: Button,
    ButtonGroup: ButtonGroup,
    Title: Title,
    Description: Description,
    buttonOrder: ['submit', 'reset', 'cancel'],
    Header: Header
  }, props));
};

export default WrappedFormTemplate;

==> carbon-component-mapper-3.11.4.tgz: package/esm/form-template/form-template.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import React from 'react';
import PropTypes from 'prop-types';
import clsx from 'clsx';
import { createUseStyles } from "react-jss/dist/react-jss.esm.js";
import CarbonForm from "carbon-components-react/es/components/Form/Form.js";
import CarbonButton from "carbon-components-react/es/components/Button/Button.js";
import ButtonSet from "carbon-components-react/es/components/ButtonSet/ButtonSet.js";
import FormTemplate from '@data-driven-forms/common/form-template';
var useStyles = createUseStyles({
  buttons: {
    marginTop: 48
  },
  header: {
    marginBottom: 40,
    div: {
      marginTop: 8
    }
  },
  form: {
    '&>:not(:last-child)': {
      marginBottom: 32
    }
  }
});
export var Button = function Button(_ref) {
  var label = _ref.label,
      buttonType = _ref.buttonType,
      props = _objectWithoutProperties(_ref, ["label", "buttonType"]);

  return /*#__PURE__*/React.createElement(CarbonButton, _extends({
    kind: buttonType === 'submit' ? 'primary' : 'secondary'
  }, props), label);
};
Button.propTypes = {
  label: PropTypes.oneOfType([PropTypes.arrayOf(PropTypes.node), PropTypes.node]),
  buttonType: PropTypes.string
};
export var ButtonGroup = function ButtonGroup(_ref2) {
  var children = _ref2.children,
      className = _ref2.className,
      props = _objectWithoutProperties(_ref2, ["children", "className"]);

  var _useStyles = useStyles(),
      butttons = _useStyles.butttons;

  return /*#__PURE__*/React.createElement(ButtonSet, _extends({}, props, {
    className: clsx(butttons, className)
  }), children);
};
ButtonGroup.propTypes = {
  children: PropTypes.oneOfType([PropTypes.arrayOf(PropTypes.node), PropTypes.node]),
  className: PropTypes.string
};
export var Title = function Title(_ref3) {
  var children = _ref3.children,
      props = _objectWithoutProperties(_ref3, ["children"]);

  return /*#__PURE__*/React.createElement("h3", props, children);
};
Title.propTypes = {
  children: PropTypes.oneOfType([PropTypes.arrayOf(PropTypes.node), PropTypes.node])
};
export var Description = function Description(_ref4) {
  var children = _ref4.children,
      props = _objectWithoutProperties(_ref4, ["children"]);

  return /*#__PURE__*/React.createElement("div", props, children);
};
Description.propTypes = {
  children: PropTypes.oneOfType([PropTypes.arrayOf(PropTypes.node), PropTypes.node])
};
export var Form = function Form(_ref5) {
  var children = _ref5.children,
      className = _ref5.className,
      props = _objectWithoutProperties(_ref5, ["children", "className"]);

  var _useStyles2 = useStyles(),
      form = _useStyles2.form;

  return /*#__PURE__*/React.createElement(CarbonForm, _extends({
    noValidate: true
  }, props, {
    className: clsx(form, className)
  }), children);
};
Form.propTypes = {
  children: PropTypes.oneOfType([PropTypes.arrayOf(PropTypes.node), PropTypes.node]),
  className: PropTypes.string
};
export var Header = function Header(props) {
  var _useStyles3 = useStyles(),
      header = _useStyles3.header;

  return /*#__PURE__*/React.createElement("div", _extends({
    className: header
  }, props));
};

var WrappedFormTemplate = function WrappedFormTemplate(props) {
  return /*#__PURE__*/React.createElement(FormTemplate, _extends({
    FormWrapper: Form,
    Button: Button,
    ButtonGroup: ButtonGroup,
    Title: Title,
    Description: Description,
    buttonOrder: ['submit', 'reset', 'cancel'],
    Header: Header
  }, props));
};

export default WrappedFormTemplate;
